# schrankwand.py
# Version 5 zweite Alternative:
# mit den Methoden FuegeHinzu() und Entferne()
# und der Methode Update in Moebel 

from grafikfenster import *

from moebel import Moebel
from schrank import Schrank

### ---------------------------------------------------
class Schrankwand(Moebel):
    '''Die Klasse Schrankwand erzeugt Objekte, die aus
    mehreren Schrankobjekten bestehen koennen.
    Begonnen wird mit einer leeren Schrankwand.'''
    def __init__(self,
                 xPos=50,
                 yPos=150,
                 winkel=0,
                 farbe="brown",
                 sichtbar=False):
        Moebel.__init__(self, xPos, yPos, 0, 0, winkel, farbe, sichtbar)
        self.__schraenke = []
        
    def GibFigur(self):
        """definiert die zu zeichnende Figur"""
        path = self.GibZeichenPfad()

        for schrank in self.__schraenke:
            path.AddPath(schrank.GibFigur())

        return self.Transformiere(path)

    def FuegeHinzu(self, schrank):
        '''fuegt einen Schrank am Ende der Liste hinzu,
        raeumlich aber nicht positionsgerecht'''
        if schrank in self.__schraenke: return
        self.__schraenke.append(schrank)
        self._AktualisiereAbmessungen()
        self.Update()
    
    def Entferne(self, schrank=None):
        '''entfernt das uebergebene Schrankobjekt
        bei None, das letzte der Liste'''
        if schrank==None:
            schrank=self.GibSchrank(len(self.__schraenke))
        if schrank in self.__schraenke:
            self.__schraenke.remove(schrank)
            self._AktualisiereAbmessungen()
        self.Update()

    def _AktualisiereAbmessungen(self):
        """setzt breite und tiefe neu"""
        # Figur darf fuer GetBox nicht gedreht sein, daher
        winkel = self.GibWinkel()
        self.Drehe(-winkel)
        daten=self.GibFigur().GetBox().Get()
        self.Drehe(winkel)
        self.AendereBreite(int(daten[2])-2)
        self.AendereTiefe(int(daten[3])-2)

## sinnvolle Ergaenzung
    def GibSchrank(self, position):
        '''gibt das Schrankobjekt an der Position der Liste zurueck
        Position 1 bis laenge'''
        if position<=0: return None
        if position>len(self.__schraenke): return None
        return self.__schraenke[position-1]
    
### ---------------------------------------------------
class SchrankwandApp(wx.App):
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.TestAnwendung()
        self.fenster.ZeigeShellFrame()
        #self.fenster.ZeigeFillingFrame()
        return True

    def BildExport(self, dateiname='bild.png'):
        '''exportiert im png- oder jpg-Format'''
        self.fenster.panel.BildExport(dateiname)

    def TestAnwendung(self):
        # Allein fuer die Testanwendung:
        global schrankwand,schrank1,schrank2,schrank3
        schrankwand=Schrankwand(sichtbar=True)
        schrank1=Schrank(0,0,60,37,0)
        schrankwand.FuegeHinzu(schrank1)
        schrank2=Schrank(60,0,60,37,0)
        schrankwand.FuegeHinzu(schrank2)
        schrank3=Schrank(120,0,60,37,0)
        schrankwand.FuegeHinzu(schrank3)

    def TestDrehen(self):
        schrankwand.Drehe(30)

    def TestHinzuFuegen(self):
        global schrank4
        schrank4=Schrank(180,0,60,37)
        schrankwand.FuegeHinzu(schrank4)
        
    def TestEntfernen(self):
        '''entfernt den letzten Schrank der Liste'''
        schrankwand.Entferne()

### ---------------------------------------------------
if __name__ == '__main__':
    app = SchrankwandApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
