# tischgruppe.py
# Version 5 -> Tischgruppe

from grafikfenster import *

from moebel import Moebel
from tisch import Tisch
from stuhl import Stuhl

### ----- Einfuegen zur Laufzeit -------------
class Tischgruppe(Moebel):
    '''die Tischgruppe wird zunaechst leer erzeugt'''
    def __init__(self,
                 xPos=0,
                 yPos=0,
                 winkel=0,
                 farbe="black",
                 sichtbar=True):
        self.__moebel=[]
        Moebel.__init__(self, xPos, yPos, 0, 0, winkel, farbe, sichtbar)
        
    def GibFigur(self):
        """definiert die zu zeichnende Figur"""
        path = self.GibZeichenPfad()

        # lokale Hilfsvariable
        ##b,t=self.GibBreite(), self.GibTiefe()

        for moebel in self.__moebel:
            path.AddPath(moebel.GibFigur())

        return self.Transformiere(path)

    def GibAlleMoebel(self):
        '''Gibt alle Moebel der Gruppe zurueck'''
        return self.__moebel

    def GibAnzahl(self):
        return len(self.__moebel)

    def FuegeHinzu(self, moebel):
        '''Fuegt das Moebel hinzu'''
        if moebel in self.__moebel: return
        self.__moebel.append(moebel)
        self._AktualisiereAbmessungen()
        self.Update()

    def Entferne(self, moebel=None, nummer=0):
        '''entfernt das Moebel'''
        fehler=False
        if moebel==None:
            if nummer==0: fehler=True # nichts zu tun
            if (nummer<1) or (nummer>self.GibAnzahl()): fehler=True
        if (moebel!=None):
            if nummer!=0: fehler=True # unklare Auswahl            
            if not(moebel in self.__moebel) : fehler=True
        if fehler:
            print('fehlerhafter Aufruf')
            return
        if (moebel==None):
            moebel=self.__moebel[nummer-1]
        self.__moebel.remove(moebel)
        self._AktualisiereAbmessungen()
        self.Update()
        
    def _AktualisiereAbmessungen(self):
        """setzt breite und tiefe neu"""
        # Figur darf fuer GetBox nicht gedreht sein, daher
        winkel = self.GibWinkel()
        self.Drehe(-winkel)
        daten=self.GibFigur().GetBox().Get()
        self.Drehe(winkel)
        self.AendereBreite(int(daten[2])-2)
        self.AendereTiefe(int(daten[3])-2)
### ===================================================
class TischgruppeApp(wx.App):
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.TestAnwendung()
        self.TestTischHinzufuegen()
        self.TestStuhlHinzufuegen()
        self.fenster.ZeigeShellFrame()
        #self.fenster.ZeigeFillingFrame()
        return True

    def TestAnwendung(self):
        global tischgruppe
        tischgruppe=Tischgruppe()
        tischgruppe.BewegeHorizontal(100)
        tischgruppe.BewegeVertikal(100)

    def TestGuppeVervollstaendigen(self):
        tischgruppe.FuegeHinzu(Stuhl(120,0))
        tischgruppe.FuegeHinzu(Stuhl(180,60,winkel=90))
        tischgruppe.FuegeHinzu(Stuhl(60,120,winkel=180))
        tischgruppe.FuegeHinzu(Stuhl(120,120,winkel=180))
        tischgruppe.FuegeHinzu(Stuhl(0,60,winkel=270))
        print ("Anzahl Moebel: ", tischgruppe.GibAnzahl())

    def TestTischHinzufuegen(self):
        tischgruppe.FuegeHinzu(Tisch(50,50))
        print ("Anzahl Moebel: ", tischgruppe.GibAnzahl())

    def TestStuhlHinzufuegen(self):
        tischgruppe.FuegeHinzu(Stuhl(60,0))
        print ("Anzahl Moebel: ", tischgruppe.GibAnzahl())

    def TestEntferneEines(self, dieNummer=1):
        tischgruppe.Entferne(nummer=dieNummer)
        print ("Anzahl Moebel: ",tischgruppe.GibAnzahl())

    def TestDreheUm30(self):
        tischgruppe.Drehe(30)

    def TestZurueckDrehen(self):
        tischgruppe.Drehe(-30)

### ---------------------------------------------------
if __name__ == '__main__':
    app = TischgruppeApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
